about summary refs log tree commit diff
path: root/pkgs/development/python-modules/qcodes/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/python-modules/qcodes/default.nix')
-rw-r--r--pkgs/development/python-modules/qcodes/default.nix30
1 files changed, 21 insertions, 9 deletions
diff --git a/pkgs/development/python-modules/qcodes/default.nix b/pkgs/development/python-modules/qcodes/default.nix
index 5796a6de6f12e..7fbb1bb3d5593 100644
--- a/pkgs/development/python-modules/qcodes/default.nix
+++ b/pkgs/development/python-modules/qcodes/default.nix
@@ -53,14 +53,14 @@
 
 buildPythonPackage rec {
   pname = "qcodes";
-  version = "0.39.0";
+  version = "0.39.1";
   format = "pyproject";
 
   disabled = pythonOlder "3.9";
 
   src = fetchPypi {
     inherit pname version;
-    sha256 = "sha256-zKn9LN7FBxKUfYSxUV1O6fB2s/B5bQpGDZTrK4DcxmU=";
+    sha256 = "sha256-2gJ/WeynabiGB1Z66+qaUbf6/1wogf/XjIE2mCAXUZY=";
   };
 
   postPatch = ''
@@ -78,8 +78,9 @@ buildPythonPackage rec {
     broadbean
     h5netcdf
     h5py
-    ipywidgets
     ipykernel
+    ipython
+    ipywidgets
     jsonschema
     matplotlib
     numpy
@@ -87,18 +88,17 @@ buildPythonPackage rec {
     opencensus-ext-azure
     packaging
     pandas
+    pillow
     pyvisa
+    rsa
     ruamel-yaml
     tabulate
-    typing-extensions
     tqdm
+    typing-extensions
     uncertainties
     websockets
     wrapt
     xarray
-    ipython
-    pillow
-    rsa
   ] ++ lib.optionals (pythonOlder "3.10") [
     importlib-metadata
   ];
@@ -139,10 +139,22 @@ buildPythonPackage rec {
   ];
 
   disabledTestPaths = [
     # depends on qcodes-loop, causing a cyclic dependency
     "qcodes/tests/dataset/measurement/test_load_legacy_data.py"
   ];
 
+  disabledTests = [
+    # Tests are time-sensitive and power-consuming
+    # Those tests fails repeatably
+    "test_access_channels_by_slice"
+    "test_do1d_additional_setpoints_shape"
+    "test_dond_1d_additional_setpoints_shape"
+    "test_field_limits"
+    "test_get_array_in_scalar_param_data"
+    "test_get_parameter_data"
+    "test_ramp_safely"
+  ];
+
   pythonImportsCheck = [
     "qcodes"
   ];
@@ -152,8 +164,8 @@ buildPythonPackage rec {
   '';
 
   meta = with lib; {
-    homepage = "https://qcodes.github.io/Qcodes/";
     description = "Python-based data acquisition framework";
+    homepage = "https://qcodes.github.io/Qcodes/";
     changelog = "https://github.com/QCoDeS/Qcodes/releases/tag/v${version}";
     license = licenses.mit;
     maintainers = with maintainers; [ evilmav ];
@@ -139,10 +139,22 @@ buildPythonPackage rec {
 
   disabledTestPaths = [
-    # depends on qcodes-loop, causing a cyclic dependency
+    # Test depends on qcodes-loop, causing a cyclic dependency
     "qcodes/tests/dataset/measurement/test_load_legacy_data.py"
   ];